@@ -11,16 +11,13 @@ class ConfigurationClient(ApiClientBase):
 
     def set(self, config_name, content):
         try:
-            params = {
-                'file_name': config_name,
-                'base64_content': encodestring(content)
-            }
+            b = encodestring(content)
         except:
             b = encodestring(content.encode('utf-8', error='strict'))
-            params = {
-                'file_name': config_name,
-                'base64_content': b
-            }
+        params = {
+            'file_name': config_name,
+            'base64_content': b
+        }
         return self.http_post_json(self.entity_endpoint_base_url + '_set', params)
 
     def get(self, config_name):
